ZwapDynamicInput class

Inheritance

Constructors

ZwapDynamicInput({required Widget content, required Widget overlay, Color? overlayColor, Color? backgroundColor = ZwapColors.shades0, Widget builder(BuildContext, Widget)?, bool focussed = false, dynamic onOpen()?, dynamic onClose()?, Color? activeColor, Color? defaultColor, String? dynamicLabel, bool showDeleteIcon = false, void onDelete()?, bool expanded = true, double? minOverlayWidth, double borderRadius = 8, Offset translateOffset = Offset.zero, Key? key})
const
ZwapDynamicInput.customSizeContent({required Widget content, required Widget overlay, Color? overlayColor, Color? backgroundColor = ZwapColors.shades0, Widget builder(BuildContext, Widget)?, bool focussed = false, dynamic onOpen()?, Color? activeColor, Color? defaultColor, dynamic onClose()?, String? dynamicLabel, bool showDeleteIcon = false, void onDelete()?, bool expanded = true, double? minOverlayWidth, double borderRadius = 8, Offset translateOffset = Offset.zero, Key? key})
Same as ZwapDynamicInput but the content child has not a pre defined height
const

Properties

activeColor Color?
This color is used for the border on the active and hovered state
final
backgroundColor Color?
final
borderRadius double
If provided, the border radius of the input field
final
builder Widget Function(BuildContext, Widget)?
final
content Widget
final
defaultColor Color?
This color is used for the border where not on the active or hovered state
final
dynamicLabel String?
If provided, showed on the border
final
expanded bool
final
focussed bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minOverlayWidth double?
If not provided 220 is used
final
onClose → dynamic Function()?
final
onDelete → void Function()?
final
onOpen → dynamic Function()?
final
overlay Widget
final
overlayColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDeleteIcon bool
final
translateOffset Offset
Offset added to the one calculated for the overlay.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ZwapDynamicInput>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited