Opportunity class

The data model about any opportunity data

Constructors

Opportunity({required int pk, required String opportunityName, required String opportunityDescription, required IconData opportunityIcon, required Color opportunityColor})
Opportunity.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
opportunityColor Color
The color for the icon of this opportunity
final
opportunityDescription String
The description for this opportunity
final
opportunityIcon IconData
The icon data for this opportunity
final
opportunityName String
The name for this opportunity
final
pk int
The primary pk for this open to tag data model
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override