ZwapPercentIndicatorDecorations class

Constructors

ZwapPercentIndicatorDecorations({required double radius, required double lineWidth, required double backgoundLineWidth, required Color backgroundColor, required Color valueColor})
const
ZwapPercentIndicatorDecorations.descrutive({double radius = 30, double lineWidth = 6, double backgoundLineWidth = 6, Color backgroundColor = ZwapColors.error200, Color valueColor = ZwapColors.error400})
const
ZwapPercentIndicatorDecorations.success({double radius = 90, double lineWidth = 14, double backgoundLineWidth = 6, Color backgroundColor = ZwapColors.neutral200, Color valueColor = ZwapColors.success400})
const

Properties

backgoundLineWidth double
final
backgroundColor Color
final
hashCode int
The hash code for this object.
no setterinherited
lineWidth double
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueColor Color
final

Methods

copyWith({double? radius, double? lineWidth, double? backgoundLineWidth, Color? backgroundColor, Color? valueColor}) ZwapPercentIndicatorDecorations
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited