ZwapPercentWidgetDecorations class

Constructors

ZwapPercentWidgetDecorations({required Color backgroundColor, required List<BoxShadow> shadows, required EdgeInsets contentPadding, required BorderRadius borderRadius, required TextStyle titleStyle, required TextStyle subtitleStyle, required ZwapPercentIndicatorDecorations percentIndicatorDecorations, Border? border})
const
ZwapPercentWidgetDecorations.defaultDecorations({Color backgroundColor = ZwapColors.shades0, List<BoxShadow> shadows = const [ZwapShadow.levelOne], BorderRadius borderRadius = const BorderRadius.all(const Radius.circular(30)), TextStyle? titleStyle, TextStyle? subtitleStyle, Border? border, EdgeInsets contentPadding = const EdgeInsets.symmetric(horizontal: 20, vertical: 12), ZwapPercentIndicatorDecorations percentIndicatorDecorations = const ZwapPercentIndicatorDecorations.descrutive()})
ZwapPercentWidgetDecorations.flat({Color backgroundColor = ZwapColors.shades0, List<BoxShadow> shadows = const [], BorderRadius borderRadius = const BorderRadius.all(const Radius.circular(30)), TextStyle? titleStyle, TextStyle? subtitleStyle, Border? border, EdgeInsets contentPadding = const EdgeInsets.symmetric(horizontal: 20, vertical: 12), ZwapPercentIndicatorDecorations percentIndicatorDecorations = const ZwapPercentIndicatorDecorations.descrutive()})

Properties

backgroundColor Color
final
border Border?
final
borderRadius BorderRadius
final
contentPadding EdgeInsets
final
hashCode int
The hash code for this object.
no setterinherited
percentIndicatorDecorations ZwapPercentIndicatorDecorations
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadows List<BoxShadow>
final
subtitleStyle TextStyle
Prefer use styles from ZwapTypography
final
titleStyle TextStyle
Prefer use styles from ZwapTypography
final

Methods

copyWith({Color? backgroundColor, List<BoxShadow>? shadows, BorderRadius? borderRadius, Border? border, EdgeInsets? contentPadding, ZwapPercentIndicatorDecorations? percentIndicatorDecorations, TextStyle? titleStyle, TextStyle? subtitleStyle}) ZwapPercentWidgetDecorations
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited