ZwapFloatingPickerProvider<T> class

Inheritance

Constructors

ZwapFloatingPickerProvider({required GlobalKey<ZwapDynamicInputState> inputKey, required List<T> values, required String getCopy(T), void onSelected(T?)?, T? selectedValue})

Properties

getCopy String Function(T)
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
inputKey GlobalKey<ZwapDynamicInputState>
final
onSelected → void Function(T?)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedValue ↔ T?
getter/setter pair
values List<T>
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited