tooltip property
If not null a tooltip will be showed on hover
See showTooltipOnlyOnDisabledState for customizing where show the tooltip
Implementation
final String? tooltip;
If not null a tooltip will be showed on hover
See showTooltipOnlyOnDisabledState for customizing where show the tooltip
final String? tooltip;