ZwapTutorialOverlayEntry class

Inheritance

Constructors

ZwapTutorialOverlayEntry({required GlobalKey<_ZwapTutorialOverlayWrapperState> uniqueKey, bool fadeOut = true, Duration fadeOutDuration = const Duration(milliseconds: 350), required WidgetBuilder builder, bool maintainState = false, bool opaque = false})

Properties

builder → WidgetBuilder
This entry will include the widget built by this builder in the overlay at the entry's position.
finalinherited
canSizeOverlay → bool
Whether the content of this OverlayEntry can be used to size the Overlay.
finalinherited
fadeOut → bool
final
fadeOutDuration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
maintainState ↔ bool
Whether this entry must be included in the tree even if there is a fully opaque entry above it.
getter/setter pairinherited
mounted → bool
Whether the OverlayEntry is currently mounted in the widget tree.
no setterinherited
opaque ↔ bool
Whether this entry occludes the entire overlay.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object notifies its listeners.
inherited
dispose() → void
Discards any resources used by this OverlayEntry.
inherited
markNeedsBuild() → void
Cause this entry to rebuild during the next pipeline flush.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → void
Remove this entry from the overlay.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited