ZwapChipsInput<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ZwapChipsInput
Constructors
-
ZwapChipsInput({required List<
T> items, required ChipsInputItemBuilder<T> itemBuilder, required ChipsInputItemSearch<T> searchItem, List<T> selectedItems = const [], void onItemPicked(T item, bool isSelected)?, String? label, String? placeholder, Widget? noResultsWidget, String translateKey(String)?, double? itemHeigth, bool showLessItem = false, int showLessItemUntilLength = 1, List<T> ? lessItems, int maxSelectedItems = 0, String? errorMessage, bool showMaxSelectedItemsString = true, Key? key}) -
const
Properties
- errorMessage → String?
-
If not null the widget will assume a error state and
the provided errorMessage will be showed in the same place
og the max length string
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
itemBuilder
→ ChipsInputItemBuilder<
T> -
Called for build the items inside the picker overlay
final
- itemHeigth → double?
-
If not provided the text input may not be aligned
final
-
items
→ List<
T> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
-
lessItems
→ List<
T> ? -
Items showed while search text length is less than
showLessItemUntilLength
final
- maxSelectedItems → int
-
Must be positive (0 included)
final
- noResultsWidget → Widget?
-
If not provided translateKey must be not null
final
- onItemPicked → void Function(T item, bool isSelected)?
-
isSelectedis true if item has just been selectedfinal - placeholder → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchItem
→ ChipsInputItemSearch<
T> -
Called to detect if an item should be hidden after
user typed
final
-
selectedItems
→ List<
T> -
Items must be the same objects from items list
final
- showLessItem → bool
-
If true the showed items will not be all available
items until the searched text length is less than
showLessItemUntilLength
final
- showLessItemUntilLength → int
-
Number of characters needed before start showing all items
final
- showMaxSelectedItemsString → bool
-
If true and maxSelectedItems is greater than 0 then
a string is showed under the input
final
- translateKey → String Function(String)?
-
If not provided noResultsWidget must be not null
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ZwapChipsInput< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited